==> aws-cdk-scala-sagemaker_3-0.1.3-sources.jar: io/burkard/cdk/services/sagemaker/CfnModelExplainabilityJobDefinition.scala <==
package io.burkard.cdk.services.sagemaker

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnModelExplainabilityJobDefinition {

  def apply(
    internalResourceId: String,
    modelExplainabilityJobInput: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityJobInputProperty] = None,
    networkConfig: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.NetworkConfigProperty] = None,
    modelExplainabilityBaselineConfig: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityBaselineConfigProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    jobResources: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.MonitoringResourcesProperty] = None,
    roleArn: Option[String] = None,
    stoppingCondition: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.StoppingConditionProperty] = None,
    modelExplainabilityJobOutputConfig: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.MonitoringOutputConfigProperty] = None,
    modelExplainabilityAppSpecification: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityAppSpecificationProperty] = None,
    jobDefinitionName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition =
    software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.Builder
      .create(stackCtx, internalResourceId)
      .modelExplainabilityJobInput(modelExplainabilityJobInput.orNull)
      .networkConfig(networkConfig.orNull)
      .modelExplainabilityBaselineConfig(modelExplainabilityBaselineConfig.orNull)
      .tags(tags.map(_.asJava).orNull)
      .jobResources(jobResources.orNull)
      .roleArn(roleArn.orNull)
      .stoppingCondition(stoppingCondition.orNull)
      .modelExplainabilityJobOutputConfig(modelExplainabilityJobOutputConfig.orNull)
      .modelExplainabilityAppSpecification(modelExplainabilityAppSpecification.orNull)
      .jobDefinitionName(jobDefinitionName.orNull)
      .build()
}

==> aws-cdk-scala-sagemaker_3-0.2.0-sources.jar: io/burkard/cdk/services/sagemaker/CfnModelExplainabilityJobDefinition.scala <==
package io.burkard.cdk.services.sagemaker

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnModelExplainabilityJobDefinition {

  def apply(
    internalResourceId: String,
    modelExplainabilityJobInput: software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityJobInputProperty,
    jobResources: software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.MonitoringResourcesProperty,
    roleArn: String,
    modelExplainabilityJobOutputConfig: software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.MonitoringOutputConfigProperty,
    modelExplainabilityAppSpecification: software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityAppSpecificationProperty,
    networkConfig: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.NetworkConfigProperty] = None,
    modelExplainabilityBaselineConfig: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.ModelExplainabilityBaselineConfigProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    stoppingCondition: Option[software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.StoppingConditionProperty] = None,
    jobDefinitionName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition =
    software.amazon.awscdk.services.sagemaker.CfnModelExplainabilityJobDefinition.Builder
      .create(stackCtx, internalResourceId)
      .modelExplainabilityJobInput(modelExplainabilityJobInput)
      .jobResources(jobResources)
      .roleArn(roleArn)
      .modelExplainabilityJobOutputConfig(modelExplainabilityJobOutputConfig)
      .modelExplainabilityAppSpecification(modelExplainabilityAppSpecification)
      .networkConfig(networkConfig.orNull)
      .modelExplainabilityBaselineConfig(modelExplainabilityBaselineConfig.orNull)
      .tags(tags.map(_.asJava).orNull)
      .stoppingCondition(stoppingCondition.orNull)
      .jobDefinitionName(jobDefinitionName.orNull)
      .build()
}
